==> devtools_app-2.6.0.tar.gz: test/inspector_error_navigator_test.dart <==
// Copyright 2021 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.

import 'dart:collection';

import 'package:devtools_app/src/error_badge_manager.dart';
import 'package:devtools_app/src/globals.dart';
import 'package:devtools_app/src/inspector/inspector_screen.dart';
import 'package:devtools_app/src/service_manager.dart';
import 'package:flutter/material.dart';
import 'package:flutter_test/flutter_test.dart';

import 'support/mocks.dart';
import 'support/wrappers.dart';

void main() {
  setUp(() {
    setGlobal(ServiceConnectionManager, FakeServiceManager());
  });

  group('Inspector Error Navigator', () {
    Future<void> testNavigate(
      WidgetTester tester, {
      IconData tapIcon,
      int errorCount,
      int startIndex,
      int expectedIndex,
    }) async {
      var index = startIndex;
      final navigator = ErrorNavigator(
        errorIndex: index,
        errors: _generateErrors(errorCount),
        onSelectError: (newIndex) => index = newIndex,
      );

      await tester.pumpWidget(wrap(navigator));
      await tester.tap(find.byIcon(tapIcon));

      expect(index, equals(expectedIndex));
    }

    testWidgets('shows count when no selection', (WidgetTester tester) async {
      await tester.pumpWidget(wrap(
        ErrorNavigator(
            errorIndex: null,
            errors: _generateErrors(10),
            onSelectError: (_) {}),
      ));
      expect(find.text('Errors: 10'), findsOneWidget);
    });

    testWidgets('shows x/y when selected error', (WidgetTester tester) async {
      await tester.pumpWidget(wrap(
        ErrorNavigator(
            errorIndex: 0, errors: _generateErrors(10), onSelectError: (_) {}),
      ));
      expect(find.text('Error 1/10'), findsOneWidget);
    });

    testWidgets(
        'can navigate forwards',
        (WidgetTester tester) => testNavigate(tester,
            tapIcon: Icons.keyboard_arrow_down,
            errorCount: 10,
            startIndex: 5,
            expectedIndex: 6));

    testWidgets(
        'can navigate backwards',
        (WidgetTester tester) => testNavigate(tester,
            tapIcon: Icons.keyboard_arrow_up,
            errorCount: 10,
            startIndex: 5,
            expectedIndex: 4));

    testWidgets(
        'wraps forwards',
        (WidgetTester tester) => testNavigate(tester,
            tapIcon: Icons.keyboard_arrow_down,
            errorCount: 10,
            startIndex: 9,
            expectedIndex: 0));

    testWidgets(
        'wraps backwards',
        (WidgetTester tester) => testNavigate(tester,
            tapIcon: Icons.keyboard_arrow_up,
            errorCount: 10,
            startIndex: 0,
            expectedIndex: 9));
  });
}

LinkedHashMap<String, InspectableWidgetError> _generateErrors(int count) =>
    LinkedHashMap<String, InspectableWidgetError>.fromEntries(List.generate(
      count,
      (index) => MapEntry(
        'error-$index',
        InspectableWidgetError(
          'Error $index',
          'error-$index',
        ),
      ),
    ));

==> devtools_app-2.8.0.tar.gz: test/inspector_error_navigator_test.dart <==
// Copyright 2021 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.

import 'dart:collection';

import 'package:devtools_app/src/error_badge_manager.dart';
import 'package:devtools_app/src/globals.dart';
import 'package:devtools_app/src/inspector/inspector_screen.dart';
import 'package:devtools_app/src/service_manager.dart';
import 'package:devtools_test/mocks.dart';
import 'package:devtools_test/wrappers.dart';
import 'package:flutter/material.dart';
import 'package:flutter_test/flutter_test.dart';

void main() {
  setUp(() {
    setGlobal(ServiceConnectionManager, FakeServiceManager());
  });

  group('Inspector Error Navigator', () {
    Future<void> testNavigate(
      WidgetTester tester, {
      IconData tapIcon,
      int errorCount,
      int startIndex,
      int expectedIndex,
    }) async {
      var index = startIndex;
      final navigator = ErrorNavigator(
        errorIndex: index,
        errors: _generateErrors(errorCount),
        onSelectError: (newIndex) => index = newIndex,
      );

      await tester.pumpWidget(wrap(navigator));
      await tester.tap(find.byIcon(tapIcon));

      expect(index, equals(expectedIndex));
    }

    testWidgets('shows count when no selection', (WidgetTester tester) async {
      await tester.pumpWidget(wrap(
        ErrorNavigator(
            errorIndex: null,
            errors: _generateErrors(10),
            onSelectError: (_) {}),
      ));
      expect(find.text('Errors: 10'), findsOneWidget);
    });

    testWidgets('shows x/y when selected error', (WidgetTester tester) async {
      await tester.pumpWidget(wrap(
        ErrorNavigator(
            errorIndex: 0, errors: _generateErrors(10), onSelectError: (_) {}),
      ));
      expect(find.text('Error 1/10'), findsOneWidget);
    });

    testWidgets(
        'can navigate forwards',
        (WidgetTester tester) => testNavigate(tester,
            tapIcon: Icons.keyboard_arrow_down,
            errorCount: 10,
            startIndex: 5,
            expectedIndex: 6));

    testWidgets(
        'can navigate backwards',
        (WidgetTester tester) => testNavigate(tester,
            tapIcon: Icons.keyboard_arrow_up,
            errorCount: 10,
            startIndex: 5,
            expectedIndex: 4));

    testWidgets(
        'wraps forwards',
        (WidgetTester tester) => testNavigate(tester,
            tapIcon: Icons.keyboard_arrow_down,
            errorCount: 10,
            startIndex: 9,
            expectedIndex: 0));

    testWidgets(
        'wraps backwards',
        (WidgetTester tester) => testNavigate(tester,
            tapIcon: Icons.keyboard_arrow_up,
            errorCount: 10,
            startIndex: 0,
            expectedIndex: 9));
  });
}

LinkedHashMap<String, InspectableWidgetError> _generateErrors(int count) =>
    LinkedHashMap<String, InspectableWidgetError>.fromEntries(List.generate(
      count,
      (index) => MapEntry(
        'error-$index',
        InspectableWidgetError(
          'Error $index',
          'error-$index',
        ),
      ),
    ));
